Crate jules_core

Crate jules_core 

Core traits and abstractions for Jules-SDK.

Modules

activity
Activity module.
builder
Builder module.
client
Client module.
config
Config module.
conversation
Conversation module.
errors
Core error types for the Jules SDK.
message
Message module.
pagination
Pagination module.
response
Response module.
session
Session module.
source
Source module.
streaming
Streaming APIs, stream event handling, async stream abstractions, incremental responses. Streaming abstractions for incremental responses.
tool
Tool calling abstractions and APIs. This module is only available when the tools feature is enabled. Tool calling support and abstractions.
traits
Traits module for Jules-SDK core abstractions.