pub enum Role {
System,
User,
Assistant,
Tool,
}Expand description
The role of the entity that generated a message.
Variants
System
System messages provide instructions and context to the model.
User
User messages are the prompts provided by the user.
Assistant
Assistant messages are the responses generated by the model.
Tool
Tool messages provide the results of a tool call.