pub struct Message { /* private fields */ }Expand description
A single message in a conversation.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn new(role: Role, content: impl Into<String>) -> Self
pub fn new(role: Role, content: impl Into<String>) -> Self
Creates a new Message with the specified role and content.
Sourcepub fn with_tool_calls(self, tool_calls: Vec<ToolCall>) -> Self
pub fn with_tool_calls(self, tool_calls: Vec<ToolCall>) -> Self
Adds tool calls to this message.
Sourcepub fn with_tool_call_id(self, tool_call_id: impl Into<String>) -> Self
pub fn with_tool_call_id(self, tool_call_id: impl Into<String>) -> Self
Sets the tool call ID for this message.
Sourcepub fn tool_calls(&self) -> Option<&[ToolCall]>
pub fn tool_calls(&self) -> Option<&[ToolCall]>
Returns the tool calls associated with this message, if any.
Sourcepub fn tool_call_id(&self) -> Option<&str>
pub fn tool_call_id(&self) -> Option<&str>
Returns the tool call ID associated with this message, if any.